#!/bin/sh
export PATH='/usr/lib/llvm15/bin/:/usr/lib/ccache/bin:/usr/bin'
printf '%s' 'name:                 HTTP
version:              4000.4.1
visibility:           public
id:                   HTTP-4000.4.1-3gGTfxuWDCjAXelRrX6QY
key:                  HTTP-4000.4.1-3gGTfxuWDCjAXelRrX6QY
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Warrick Gray <warrick.gray@hotmail.com>
homepage:             https://github.com/haskell/HTTP
synopsis:             A library for client-side HTTP
description:
    The HTTP package supports client-side web programming in Haskell. It lets you set up
    HTTP connections, transmitting requests and processing the responses coming back, all
    from within the comforts of Haskell. It'\''s dependent on the network package to operate,
    but other than that, the implementation is all written in Haskell.

    A basic API for issuing single HTTP requests + receiving responses is provided. On top
    of that, a session-level abstraction is also on offer  (the @BrowserAction@ monad);
    it taking care of handling the management of persistent connections, proxies,
    state (cookies) and authentication credentials required to handle multi-step
    interactions with a web server.

    The representation of the bytes flowing across is extensible via the use of a type class,
    letting you pick the representation of requests and responses that best fits your use.
    Some pre-packaged, common instances are provided for you (@ByteString@, @String@).

    Here'\''s an example use:

    >
    >    do
    >      rsp <- Network.HTTP.simpleHTTP (getRequest "http://www.haskell.org/")
    >              -- fetch document and return it (as a '\''String'\''.)
    >      fmap (take 100) (getResponseBody rsp)
    >
    >    do
    >      (_, rsp)
    >         <- Network.Browser.browse $ do
    >               setAllowRedirects True -- handle HTTP redirects
    >               request $ getRequest "http://www.haskell.org/"
    >      return (take 100 (rspBody rsp))

    __Note:__ This package does not support HTTPS connections.
    If you need HTTPS, take a look at the following packages:

    * <http://hackage.haskell.org/package/http-streams http-streams>

    * <http://hackage.haskell.org/package/http-client http-client> (in combination with
    <http://hackage.haskell.org/package/http-client-tls http-client-tls>)

    * <http://hackage.haskell.org/package/req req>

    * <http://hackage.haskell.org/package/wreq wreq>

category:             Network
abi:                  c75244f3d4345a186d57665045959817
exposed:              True
exposed-modules:
    Network.Browser Network.BufferType Network.HTTP Network.HTTP.Auth
    Network.HTTP.Base Network.HTTP.Cookie Network.HTTP.HandleStream
    Network.HTTP.Headers Network.HTTP.Proxy Network.HTTP.Stream
    Network.Stream Network.StreamDebugger Network.StreamSocket
    Network.TCP

hidden-modules:
    Network.HTTP.Base64 Network.HTTP.MD5Aux Network.HTTP.Utils
    Paths_HTTP

import-dirs:          /usr/lib/ghc-9.8.2/site-local/HTTP-4000.4.1
library-dirs:         /usr/lib/ghc-9.8.2/site-local/HTTP-4000.4.1
library-dirs-static:  /usr/lib/ghc-9.8.2/site-local/HTTP-4000.4.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-9.8.2
data-dir:             /usr/share/x86_64-linux-ghc-9.8.2/HTTP-4000.4.1
hs-libraries:         HSHTTP-4000.4.1-3gGTfxuWDCjAXelRrX6QY
depends:
    array-0.5.6.0-inplace base-4.19.1.0-inplace
    bytestring-0.12.1.0-inplace mtl-2.3.1-inplace
    network-3.1.5.0-B01CCCWWHQOAL2QMfHujv6
    network-uri-2.6.4.2-1dWojNPLXrt1C0Ods6iJ1k parsec-3.1.17.0-inplace
    time-1.12.2-inplace transformers-0.6.1.0-inplace

haddock-interfaces:
    /usr/share/doc/x86_64-linux-ghc-9.8.2/HTTP-4000.4.1/html/HTTP.haddock

haddock-html:         /usr/share/doc/x86_64-linux-ghc-9.8.2/HTTP-4000.4.1/html
' | '/usr/bin/ghc-pkg-9.8.2' 'update' '-' '--global' '--no-user-package-db' "$@"

